[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --distributed-is-the-new-centralized
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


* * *
The entire **[Pro Git book](https://git-scm.com/book)** written by Scott Chacon and Ben Straub is available to [read online for free](https://git-scm.com/book). Dead tree versions are available on [Amazon.com](https://www.amazon.com/Pro-Git-Scott-Chacon/dp/1484200772?ie=UTF8&camp=1789&creative=9325&creativeASIN=1430218339&linkCode=as2&tag=git-sfconservancy-20).
#  About Git
##  Git is fast
Git was built to work on the Linux kernel, meaning that it was built to handle repositories with tens of millions of lines of code from the start. Speed and performance has always been a primary design goal of Git.
Git also stores repository history efficiently. As of 2025, the current version of the Linux kernel's source code is 1.7 GB. Git stores the full history of the Linux project (1.4 million commits) in only 5.5 GB.
##  Git is widely used
According to the [2022 Stack Overflow developer survey](https://survey.stackoverflow.co/2022/#version-control-version-control-system-prof), 96% of professional developers use Git.
##  Git has a huge ecosystem of tools
The core Git project is just a command-line tool, but Git exploded in popularity in the early 2010s thanks to [Git hosting services](https://git-scm.com/tools/hosting) like GitLab, GitHub, and more.
Since Git was created, many [GUIs](https://git-scm.com/tools/guis), editor integrations, and [command line tools](https://git-scm.com/tools/command-line) have been built to make working with Git more convenient. You favorite developer tools might already have a built-in Git integration.
## Free and Open Source
Git is released under the [ GNU General Public License version 2.0](https://opensource.org/licenses/GPL-2.0), which is an [open source license](https://opensource.org/docs/osd). The Git project chose to use GPLv2 to guarantee your freedom to share and change free software---to make sure the software is free for all its users.
However, we do restrict the use of the term "Git" and the [logos](https://git-scm.com/community/logos) to avoid confusion. Please see our [trademark](https://git-scm.com/about/trademark) policy for details.
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
